@@ -10,7 +10,6 @@ import collections
 from aldy.solutions import CNSolution, SolvedAllele, MajorSolution
 from aldy.coverage import Coverage
 from aldy.gene import Mutation
-from aldy.major import NOVEL_MUTATION_PENAL
 from aldy.minor import estimate_minor, ADD_PENALTY_FACTOR, MISS_PENALTY_FACTOR
 from aldy.common import SOLUTION_PRECISION, sorted_tuple
 
@@ -234,7 +233,7 @@ def test_phase(toy_gene, solver):
             },
             "major": ({"1": 1, "3": 1}, (100_000_110, "delAC")),
             "sol": [("1.001", [], []), ("3.001", [], [(100_000_110, "delAC")])],
-            "score": NOVEL_MUTATION_PENAL + ADD_PENALTY_FACTOR + 2,
+            "score": ADD_PENALTY_FACTOR * 1.5 + 2,
             "phase": [[(100_000_110, "delAC"), (100_000_150, "C>T")], []],
         },
     )
@@ -261,6 +260,6 @@ def test_major_novel(toy_gene, solver):
                 ("3.001", [(100_000_147, "insA")], []),
                 ("6.001", [], []),
             ],
-            "score": MISS_PENALTY_FACTOR + (ADD_PENALTY_FACTOR + NOVEL_MUTATION_PENAL),
+            "score": MISS_PENALTY_FACTOR + (ADD_PENALTY_FACTOR * 1.5),
         },
     )
